@@ -1,4 +1,4 @@
 from rand_pass_generator import generate
 
 def testFunction():
-    assert type(generate()) == str
\ No newline at end of file
+    assert type(generate()) == dict
